/* SettingDlgControl */

#import <Cocoa/Cocoa.h>
#import "option.h"

@interface SettingDlgControl : NSObject
{
    IBOutlet id checkBUFE;
    IBOutlet id checkDiscAtOnce;
    IBOutlet id checkOnTheFly;
    IBOutlet id checkTestWrite;
    IBOutlet id readSpeedSel;
    IBOutlet id settingPanel;
    IBOutlet id textTempDirectory;
    IBOutlet id writeSpeedSel;
}
- (IBAction)buttonCancel:(id)sender;
- (IBAction)buttonStart:(id)sender;
- (int)openSettingDialog:(OPTIONS *)option;
- (void)setSpeedItems:(id)target
			 defValue:(int)defaultSpeed
				isdvd:(BOOL)dvd
			speedList:(BYTE *)speeds
			 numSpeed:(int)num_speed;


@end
